@@ -36,5 +36,6 @@ class OutputPlugin(kube_common.OutputPlugin):
         data['metadata'] = self.build_metadata(app_vars['APP']['metadata'])
         data['data'] = app_vars['APP']['data']
 
-        output = yaml_dump(self._template.render_template(data, app_vars))
-        return output
+        data = self._template.render_template(data, app_vars)
+        output = yaml_dump(data)
+        return (output, self.get_output_filename_suffix(data))
